==> rest-sdk-java-generator-0.6.0-sources.jar: com/mulesoft/connectivity/rest/sdk/templating/sdk/sampledata/SdkSampleDataInline.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.templating.sdk.sampledata;

import static com.mulesoft.connectivity.rest.sdk.internal.connectormodel.parameter.ParameterType.TRIGGER;
import static com.mulesoft.connectivity.rest.sdk.templating.sdk.resolver.SdkResolverUtil.isBoundParameterForHttpBinding;
import static com.mulesoft.connectivity.rest.sdk.templating.sdk.sampledata.SdkSampleDataDefinition.SAMPLE_DATA_SUFFIX;

import com.mulesoft.connectivity.rest.commons.internal.model.dataexpressions.BindingField;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorModel;
import com.mulesoft.connectivity.rest.sdk.templating.api.RestSdkRunConfiguration;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.parameter.SdkParameter;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.resolver.AbstractSdkResolverProviderInline;

import java.nio.file.Path;
import java.util.Collections;
import java.util.List;

import com.squareup.javapoet.ClassName;
import com.squareup.javapoet.TypeName;

public class SdkSampleDataInline extends AbstractSdkResolverProviderInline {

  private final SdkSampleDataDefinition sdkResolverDefinition;
  private final List<SdkParameter> sdkParameters;
  private final String parentClassName;

  public SdkSampleDataInline(Path outputDir,
                             ConnectorModel connectorModel,
                             String parentClassName,
                             List<SdkParameter> sdkParameters,
                             SdkSampleDataDefinition sdkResolverDefinition,
                             RestSdkRunConfiguration runConfiguration) {
    super(outputDir, connectorModel, sdkResolverDefinition, runConfiguration);
    this.sdkResolverDefinition = sdkResolverDefinition;
    this.sdkParameters = sdkParameters;
    this.parentClassName = parentClassName;
  }

  public String getPackage() {
    return connectorModel.getBasePackage() + ".internal.metadata.sample";
  }

  public String getJavaClassName() {
    return parentClassName + SAMPLE_DATA_SUFFIX;
  }

  @Override
  protected List<SdkParameter> getAllParameters() {
    return sdkParameters;
  }

  @Override
  protected List<BindingField> getBindingFields() {
    return Collections.emptyList();
  }

  @Override
  protected String getEvaluationContextKind() {
    return sdkResolverDefinition.getEvaluationContextKind();
  }

  @Override
  protected TypeName getSuperClass() {
    return ClassName.get(sdkResolverDefinition.getSuperclass());
  }

  @Override
  protected boolean isBoundParameter(SdkParameter sdkParameter) {
    if (sdkParameter.getParameterType().equals(TRIGGER)) {
      return true;
    }

    return isBoundParameterForHttpBinding(sdkParameter,
                                          sdkResolverDefinition.getDefinition().getResult().getHttpRequestBinding());
  }

}

==> rest-sdk-java-generator-0.9.0-sources.jar: com/mulesoft/connectivity/rest/sdk/templating/sdk/sampledata/SdkSampleDataInline.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.templating.sdk.sampledata;

import static com.mulesoft.connectivity.rest.sdk.templating.sdk.resolver.SdkResolverUtil.getBodyFieldsFromHttpBinding;
import static com.mulesoft.connectivity.rest.sdk.templating.sdk.resolver.SdkResolverUtil.isBoundParameterForHttpBinding;
import static com.mulesoft.connectivity.rest.sdk.templating.sdk.sampledata.SdkSampleDataDefinition.SAMPLE_DATA_SUFFIX;
import static java.util.Collections.emptyList;

import com.mulesoft.connectivity.rest.commons.internal.model.dataexpressions.BindingField;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorModel;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.sampledata.SampleDataDefinition;
import com.mulesoft.connectivity.rest.sdk.templating.api.RestSdkRunConfiguration;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.parameter.SdkParameter;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.resolver.AbstractSdkResolverProviderInline;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.resolver.SdkResolverUtil;

import java.nio.file.Path;
import java.util.List;

import com.squareup.javapoet.ClassName;
import com.squareup.javapoet.TypeName;

public class SdkSampleDataInline extends AbstractSdkResolverProviderInline {

  private final SdkSampleDataDefinition sdkResolverDefinition;
  private final List<SdkParameter> sdkParameters;
  private final String parentClassName;

  public SdkSampleDataInline(Path outputDir,
                             ConnectorModel connectorModel,
                             String parentClassName,
                             List<SdkParameter> sdkParameters,
                             SdkSampleDataDefinition sdkResolverDefinition,
                             RestSdkRunConfiguration runConfiguration) {
    super(outputDir, connectorModel, sdkResolverDefinition, runConfiguration);
    this.sdkResolverDefinition = sdkResolverDefinition;
    this.sdkParameters = sdkParameters;
    this.parentClassName = parentClassName;
  }

  public String getPackage() {
    return connectorModel.getBasePackage() + ".internal.metadata.sample";
  }

  public String getJavaClassName() {
    return parentClassName + SAMPLE_DATA_SUFFIX;
  }

  @Override
  protected List<SdkParameter> getAllParameters() {
    return sdkParameters;
  }

  @Override
  protected List<BindingField> getBindingFields() {
    if (sdkResolverDefinition.getDefinition().getResult() == null) {
      return emptyList();
    }
    return getBodyFieldsFromHttpBinding(sdkResolverDefinition.getDefinition().getResult().getHttpRequestBinding());
  }

  @Override
  protected String getEvaluationContextKind() {
    return sdkResolverDefinition.getEvaluationContextKind();
  }

  @Override
  protected TypeName getSuperClass() {
    return ClassName.get(sdkResolverDefinition.getSuperclass());
  }

  @Override
  protected boolean isBoundParameter(SdkParameter sdkParameter) {
    SampleDataDefinition definition = sdkResolverDefinition.getDefinition();
    return ((definition.getResult() != null
        ? isBoundParameterForHttpBinding(sdkParameter, definition.getResult().getHttpRequestBinding())
        : false)
        || isBoundParameterInTransformation(sdkParameter, definition)
        || isBoundParameterInScript(sdkParameter, definition));
  }

  private boolean isBoundParameterInTransformation(SdkParameter sdkParameter, SampleDataDefinition definition) {
    if (definition.getTransformation() == null) {
      return false;
    }
    return SdkResolverUtil.isBoundScript(sdkParameter, definition.getTransformation().getExpression());
  }

  private boolean isBoundParameterInScript(SdkParameter sdkParameter, SampleDataDefinition definition) {
    if (definition.getScript() == null) {
      return false;
    }
    return SdkResolverUtil.isBoundScript(sdkParameter, definition.getScript());
  }

}
